@@ -3,7 +3,9 @@ package MooseX::Signature::Function::Interface::Signature;
 use Moose::Role;
 
 requires qw/
-  validate
+  is_subset_of
+  validate_input
+  validate_output
   /;
 
 1;
